[Libreoffice-commits] core.git: sw/source

Caolán McNamara caolanm at redhat.com
Thu Apr 9 01:13:01 PDT 2015


 sw/source/core/doc/DocumentRedlineManager.cxx |    8 ++++----
 sw/source/filter/ww8/wrtw8nds.cxx             |    2 +-
 sw/source/filter/ww8/wrtww8.cxx               |    2 +-
 sw/source/filter/ww8/ww8graf2.cxx             |    6 +++---
 sw/source/filter/ww8/ww8par.cxx               |    2 +-
 5 files changed, 10 insertions(+), 10 deletions(-)

New commits:
commit e68c699b7e7efdf3678b450124b9e08ee227ddb9
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Apr 9 08:48:06 2015 +0100

    hinter: 'after' better than 'behind'
    
    this has niggled me for decades
    
    http://german.stackexchange.com/questions/7528/meaning-of-behind-when-translated-from-german
    
    summarizes it well
    
    "'Behind' is typically used when the context has meanings of depth, and as such
    becomes ambiguous when used in a flat list ... 'After'/'before' contain
    meanings of ordering which are unambiguous"
    
    Change-Id: Ib2e7244f1dc0a66a9ca30df3a20e31de7a9b9d09

diff --git a/sw/source/filter/ww8/wrtw8nds.cxx b/sw/source/filter/ww8/wrtw8nds.cxx
index 340613a..0edd7db5 100644
--- a/sw/source/filter/ww8/wrtw8nds.cxx
+++ b/sw/source/filter/ww8/wrtw8nds.cxx
@@ -1776,7 +1776,7 @@ void MSWordExportBase::UpdatePosition( SwWW8AttrIter* aAttrIter, sal_Int32 nAktP
 {
     sal_Int32 nNextPos;
 
-    // go to next attribute if no bookmark is found or if the bookmark is behind the next attribute position
+    // go to next attribute if no bookmark is found or if the bookmark is after the next attribute position
     // It may happened that the WhereNext() wasn't used in the previous increment because there was a
     // bookmark before it. Use that position before trying to find another one.
     bool bNextBookmark = NearestBookmark( nNextPos, nAktPos, true );
diff --git a/sw/source/filter/ww8/wrtww8.cxx b/sw/source/filter/ww8/wrtww8.cxx
index 0dcd026..5836891 100644
--- a/sw/source/filter/ww8/wrtww8.cxx
+++ b/sw/source/filter/ww8/wrtww8.cxx
@@ -1090,7 +1090,7 @@ bool WW8_WrFkp::Append( WW8_FC nEndFc, sal_uInt16 nVarLen, const sal_uInt8* pSpr
     }
 
     if( (sal_uInt16)nPos <= ( nIMax + 2U ) * 4U + ( nIMax + 1U ) * nItemSize )
-                                            // does it fits behind the CPs and offsets?
+                                            // does it fits after the CPs and offsets?
         return false;                       // no
 
     reinterpret_cast<sal_Int32*>(pFkp)[nIMax + 1] = nEndFc;     // insert FC
diff --git a/sw/source/filter/ww8/ww8graf2.cxx b/sw/source/filter/ww8/ww8graf2.cxx
index 4752969..275ac54 100644
--- a/sw/source/filter/ww8/ww8graf2.cxx
+++ b/sw/source/filter/ww8/ww8graf2.cxx
@@ -495,9 +495,9 @@ SwFrmFmt* SwWW8ImplReader::ImportGraf(SdrTextObj* pTextObj,
 
             WW8FlySet aFlySet( *this, pPaM, aPic, aPD.nWidth, aPD.nHeight );
 
-            // the correct anchor is set in Read_F_IncludePicture and the current PaM point's
-            // behind the position if it is anchored in content; because this anchor add
-            // a character into the textnode. IussueZilla task 2806
+            // the correct anchor is set in Read_F_IncludePicture and the current PaM point
+            // is after the position if it is anchored in content; because this anchor add
+            // a character into the textnode. #i2806#
             if (FLY_AS_CHAR ==
                 pFlyFmtOfJustInsertedGraphic->GetAnchor().GetAnchorId() )
             {
diff --git a/sw/source/filter/ww8/ww8par.cxx b/sw/source/filter/ww8/ww8par.cxx
index 282f4b5..ab30cee 100644
--- a/sw/source/filter/ww8/ww8par.cxx
+++ b/sw/source/filter/ww8/ww8par.cxx
@@ -150,7 +150,7 @@ using namespace nsHdFtFlags;
 //#define VT_LPWSTR           31
 //#define VT_BLOB             65
 //#define VT_TYPEMASK         0xFFF
-/** Expands to a pointer behind the last element of a STATIC data array (like STL end()). */
+/** Expands to a pointer after the last element of a STATIC data array (like STL end()). */
 //#define STATIC_TABLE_END( array )   ((array)+STATIC_TABLE_SIZE(array))
 /** Expands to the size of a STATIC data array. */
 //#define STATIC_TABLE_SIZE( array )  (sizeof(array)/sizeof(*(array)))


More information about the Libreoffice-commits mailing list
diff --git a/sw/source/core/doc/DocumentRedlineManager.cxx b/sw/source/core/doc/DocumentRedlineManager.cxx
index 4fb65aa..ba5ddad 100644
--- a/sw/source/core/doc/DocumentRedlineManager.cxx
+++ b/sw/source/core/doc/DocumentRedlineManager.cxx
@@ -41,7 +41,7 @@ using namespace com::sun::star;
         // helper function for lcl_CheckRedline
         // 1. make sure that pPos->nContent points into pPos->nNode
         //    (or into the 'special' no-content-node-IndexReg)
         // 2. check that position is valid and doesn't point behind text
         static void lcl_CheckPosition( const SwPosition* pPos )
         {
             SwPosition aComparePos( *pPos );
@@ -61,7 +61,7 @@ using namespace com::sun::star;
             {
                 OSL_ENSURE( pPos->nContent >= 0  &&
                             pPos->nContent <= pTxtNode->Len(),
-                            _ERROR_PREFIX "index behind text" );
+                            _ERROR_PREFIX "index after text" );
             }
         }
 
@@ -771,7 +771,7 @@ bool DocumentRedlineManager::AppendRedline( SwRangeRedline* pNewRedl, bool bCall
             {
                 if( pStt->nContent > pTxtNode->Len() )
                 {
-                    OSL_ENSURE( false, "Redline start: index behind text" );
+                    OSL_ENSURE( false, "Redline start: index after text" );
                     pStt->nContent = pTxtNode->Len();
                 }
             }
@@ -788,7 +788,7 @@ bool DocumentRedlineManager::AppendRedline( SwRangeRedline* pNewRedl, bool bCall
             {
                 if( pEnd->nContent > pTxtNode->Len() )
                 {
-                    OSL_ENSURE( false, "Redline end: index behind text" );
+                    OSL_ENSURE( false, "Redline end: index after text" );
                     pEnd->nContent = pTxtNode->Len();
                 }
             }
@@ -41,7 +41,7 @@ using namespace com::sun::star;
         // 1. make sure that pPos->nContent points into pPos->nNode
         //    (or into the 'special' no-content-node-IndexReg)
-        // 2. check that position is valid and doesn't point behind text
+        // 2. check that position is valid and doesn't point after text
         static void lcl_CheckPosition( const SwPosition* pPos )
         {